==> jc-1.4.0.tar.gz: ppg/parse/ParseTest.h <==
// public class ppg.parse.ParseTest

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ca3d37598e3b6df4 ppg_parse_ParseTest

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_parse_ParseTest_H_
#define _JC_ppg_parse_ParseTest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_parse_ParseTest$sub_refs	_jc_ppg_parse_ParseTest$sub_refs;
typedef struct _jc_ppg_parse_ParseTest$sub_nonrefs	_jc_ppg_parse_ParseTest$sub_nonrefs;
typedef struct _jc_ppg_parse_ParseTest$refs	_jc_ppg_parse_ParseTest$refs;
typedef struct _jc_ppg_parse_ParseTest$nonrefs	_jc_ppg_parse_ParseTest$nonrefs;
typedef struct _jc_ppg_parse_ParseTest$object	_jc_ppg_parse_ParseTest$object;

typedef struct _jc_ppg_parse_ParseTest$fields_struct	_jc_ppg_parse_ParseTest$fields_struct;
typedef const struct _jc_ppg_parse_ParseTest$vmethods	_jc_ppg_parse_ParseTest$vmethods;
typedef const struct _jc_ppg_parse_ParseTest$vtable	_jc_ppg_parse_ParseTest$vtable;
typedef const struct _jc_ppg_parse_ParseTest$vtype	_jc_ppg_parse_ParseTest$vtype;

// Class fields structure
struct _jc_ppg_parse_ParseTest$fields_struct {
	struct _jc_java_lang_String$object	*HEADER;
};
extern _jc_ppg_parse_ParseTest$fields_struct _jc_ppg_parse_ParseTest$class_fields;

// Constructors
extern void _jc_ppg_parse_ParseTest$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_parse_ParseTest$object *);

// Static methods
extern void _jc_ppg_parse_ParseTest$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_ppg_parse_ParseTest$vmethods {
};

// Vtable
struct _jc_ppg_parse_ParseTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_parse_ParseTest$vmethods	ppg_parse_ParseTest;
};

// Vtype
struct _jc_ppg_parse_ParseTest$vtype {
	_jc_type			type;
	_jc_ppg_parse_ParseTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_parse_ParseTest$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_parse_ParseTest$refs {
    _jc_ppg_parse_ParseTest$sub_refs	ppg_parse_ParseTest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_parse_ParseTest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_parse_ParseTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_parse_ParseTest$sub_nonrefs	ppg_parse_ParseTest;
};

// Object instance structure
struct _jc_ppg_parse_ParseTest$object {
	_jc_ppg_parse_ParseTest$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_parse_ParseTest$vtype	*vtype;
	_jc_ppg_parse_ParseTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_parse_ParseTest$vtype _jc_ppg_parse_ParseTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_parse_ParseTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_parse_ParseTest$class_object;

#endif	/* _JC_ppg_parse_ParseTest_H_ */

==> jc-1.4.6.tar.gz: ppg/parse/ParseTest.h <==
// public class ppg.parse.ParseTest

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ca3d37598e3b6df4 ppg_parse_ParseTest

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_parse_ParseTest_H_
#define _JC_ppg_parse_ParseTest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_parse_ParseTest$sub_refs	_jc_ppg_parse_ParseTest$sub_refs;
typedef struct _jc_ppg_parse_ParseTest$sub_nonrefs	_jc_ppg_parse_ParseTest$sub_nonrefs;
typedef struct _jc_ppg_parse_ParseTest$refs	_jc_ppg_parse_ParseTest$refs;
typedef struct _jc_ppg_parse_ParseTest$nonrefs	_jc_ppg_parse_ParseTest$nonrefs;
typedef struct _jc_ppg_parse_ParseTest$object	_jc_ppg_parse_ParseTest$object;

typedef struct _jc_ppg_parse_ParseTest$fields_struct	_jc_ppg_parse_ParseTest$fields_struct;
typedef const struct _jc_ppg_parse_ParseTest$vmethods	_jc_ppg_parse_ParseTest$vmethods;
typedef const struct _jc_ppg_parse_ParseTest$vtable	_jc_ppg_parse_ParseTest$vtable;
typedef const struct _jc_ppg_parse_ParseTest$vtype	_jc_ppg_parse_ParseTest$vtype;

// Class fields structure
struct _jc_ppg_parse_ParseTest$fields_struct {
	struct _jc_java_lang_String$object	*HEADER;
};
extern _jc_ppg_parse_ParseTest$fields_struct _jc_ppg_parse_ParseTest$class_fields;

// Constructors
extern void _jc_ppg_parse_ParseTest$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_parse_ParseTest$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_ppg_parse_ParseTest$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_ppg_parse_ParseTest$vmethods {
};

// Vtable
struct _jc_ppg_parse_ParseTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_parse_ParseTest$vmethods	ppg_parse_ParseTest;
};

// Vtype
struct _jc_ppg_parse_ParseTest$vtype {
	_jc_type			type;
	_jc_ppg_parse_ParseTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_parse_ParseTest$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_parse_ParseTest$refs {
    _jc_ppg_parse_ParseTest$sub_refs	ppg_parse_ParseTest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_parse_ParseTest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_parse_ParseTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_parse_ParseTest$sub_nonrefs	ppg_parse_ParseTest;
};

// Object instance structure
struct _jc_ppg_parse_ParseTest$object {
	_jc_ppg_parse_ParseTest$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_parse_ParseTest$vtype	*vtype;
	_jc_ppg_parse_ParseTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_parse_ParseTest$vtype _jc_ppg_parse_ParseTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_parse_ParseTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_parse_ParseTest$class_object;

#endif	/* _JC_ppg_parse_ParseTest_H_ */
